<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              piwebsolution.com
 * @since             1.4.34
 * @package           Pisol_Delivery_Pickup_Reminder_Email
 *
 * @wordpress-plugin
 * Plugin Name:       Delivery pickup reminder email Woocommerce
 * Plugin URI:        piwebsolution.com/shop
 * Description:       Send a reminder email to customer regarding there order pickup or delivery
 * Version:           1.4.34
 * Author:            PI Websolution
 * Author URI:        piwebsolution.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       pisol-delivery-pickup-reminder-email
 * WC tested up to:   8.6.0
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

if(!is_plugin_active( 'woocommerce/woocommerce.php')){
    function dpre_free_woocommerce_error_notice() {
        ?>
        <div class="error notice">
            <p><?php _e( 'Please Install and Activate WooCommerce plugin, without that this plugin can\'t work.', 'pisol-delivery-pickup-reminder-email' ); ?></p>
        </div>
        <?php
    }
    add_action( 'admin_notices', 'dpre_free_woocommerce_error_notice' );
    deactivate_plugins(plugin_basename(__FILE__));
    return;
}

if(is_plugin_active( 'delivery-pickup-reminder-email-woocommerce-pro/delivery-pickup-reminder-email-woocommerce-pro.php')){
	
	function dpre_free_error_notice() {
        ?>
        <div class="error notice">
            <p><?php _e( 'You already have the PRO version of Delivery pickup reminder email.', 'pisol-delivery-pickup-reminder-email' ); ?></p>
        </div>
        <?php
    }
    add_action( 'admin_notices', 'dpre_free_error_notice' );
    deactivate_plugins(plugin_basename(__FILE__));
    return;

}else{


/**
 * Currently plugin version.
 * Start at version 1.4.34 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PISOL_DELIVERY_PICKUP_REMINDER_EMAIL_VERSION', '1.4.34' );
define( 'PISOL_DPRE_REMINDER_URL', plugin_dir_url(__FILE__));
define( 'PISOL_DPRE_REMINDER_BUY_URL', 'https://www.piwebsolution.com/cart/?add-to-cart=5195&variation_id=5199');
define( 'PISOL_DPRE_REMINDER_PRICE', '$16 Only');

/**
 * Declare compatible with HPOS new order table 
 */
add_action( 'before_woocommerce_init', function() {
	if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
	}
} );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-pisol-delivery-pickup-reminder-email-activator.php
 */
function activate_pisol_delivery_pickup_reminder_email() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-pisol-delivery-pickup-reminder-email-activator.php';
	Pisol_Delivery_Pickup_Reminder_Email_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-pisol-delivery-pickup-reminder-email-deactivator.php
 */
function deactivate_pisol_delivery_pickup_reminder_email() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-pisol-delivery-pickup-reminder-email-deactivator.php';
	Pisol_Delivery_Pickup_Reminder_Email_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_pisol_delivery_pickup_reminder_email' );
register_deactivation_hook( __FILE__, 'deactivate_pisol_delivery_pickup_reminder_email' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-pisol-delivery-pickup-reminder-email.php';


function run_pisol_delivery_pickup_reminder_email() {

	$plugin = new Pisol_Delivery_Pickup_Reminder_Email();
	$plugin->run();

}
run_pisol_delivery_pickup_reminder_email();

}