<?php

class pisol_pdpr_email_reminder{
    
    function __construct($order_id){
        $this->order = wc_get_order($order_id);
        $this->order_id = $order_id;

        if(!$this->emailAllowed()) return;

        $this->type = $this->order->get_meta('pi_delivery_type', true);
        $this->date = $this->order->get_meta('pi_system_delivery_date', true);
        $this->time = $this->order->get_meta('pi_delivery_time', true);
        $this->location = $this->order->get_meta('pickup_location_id', true);
        $this->location_text = $this->order->get_meta('pickup_location', true);

        $this->customer_email = $this->emailId();

        $this->delivery_time = $this->deliveryTime();

        $this->delivery_type = $this->deliveryType();

        $this->delivery_date = $this->deliveryDate( );

        $this->pickup_location = $this->pickupLocation( );

        $this->subject = $this->subject();

        $this->heading = $this->heading();

        $this->custom_message = $this->customMessage();

        $this->message = $this->message();

        $this->sendEmail();
    }

    function emailId(){
        $customer_email = $this->order->get_billing_email();
        $admin_reminder = get_option('pi_enable_reminder_email_admin',1);
        if(!empty($admin_reminder)){
            $admin_email = get_bloginfo('admin_email');
            return $customer_email.', '.$admin_email;
        }
        return $customer_email;
    }

    function emailAllowed(){
        $not_allowed_order_state = get_option('pi_dont_send_reminder_if_order_status_is',array('wc-cancelled', 'wc-refunded', 'wc-failed'));

        $order_status = 'wc-'.$this->order->get_status();
        if(in_array($order_status, $not_allowed_order_state)){
            return false;
        }
        return true;
    }

    function deliveryDetails(){
        $html = "";
        if(!empty($this->type)){
            $html .= '<p><strong>'.__('Delivery type: ','pisol-delivery-pickup-reminder-email').'</strong>'.$this->delivery_type.'</p>';
        }
        if(!empty($this->date)){
            $html .= '<p><strong>'.__('Delivery date: ','pisol-delivery-pickup-reminder-email').'</strong>'.$this->delivery_date.'</p>';
        }

        if(!empty($this->time)){
            $html .= '<p><strong>'.__('Delivery time: ','pisol-delivery-pickup-reminder-email').'</strong>'.$this->delivery_time.'</p>';
        }

        if(!empty($this->pickup_location)){
            $html .= '<p><strong>'.__('Delivery location: ','pisol-delivery-pickup-reminder-email').'</strong>'. $this->pickup_location.'</p>';
        }

        return $html;

    }

    function pickupLocation(){
        if(!empty($this->location)){
            $title = get_the_title($this->location);
            $address = get_the_content($this->location);

            $location = '<p>'.$title.'</p><p>'.$address.'</p>';
            return $location;
        }else{
            return $this->location_text;
        }
    }

    function subject(){
        $variable = 'pi_email_subject';
        $subject = get_option($variable, 'Order #{order} on {delivery_date} at {delivery_time}');
        return $this->replaceShortCode($subject);
    }

    function heading(){
        $variable = 'pi_email_heading';
        $subject = get_option($variable, 'Order #{order} on {delivery_date} at {delivery_time}');
        return $this->replaceShortCode($subject);
    }

    function customMessage(){
        $variable = 'pi_email_message';
        $subject = get_option($variable, 'Order #{order} on {delivery_date} at {delivery_time}');
        return $this->replaceShortCode($subject);
    }

    function deliveryTime(){
        $time = $this->time;
        if(empty($time)) return __('No time given','pisol-delivery-pickup-reminder-email');

        return self::formatTimeForDisplay($time);

    }

    function deliveryDate( ){
        $date = $this->date;
        $datestamp = DateTime::createFromFormat("Y/m/d", $date);
        $date = date_i18n(get_option( 'date_format' ), $datestamp->getTimestamp());
        return $date;
    }

    function deliveryType(){
        $type = $this->type;
        return $type == 'pickup' ? __('Pickup','pisol-delivery-pickup-reminder-email') : __('Delivery','pisol-delivery-pickup-reminder-email');
    }

    function replaceShortCode($msg){
        $find = array(
            '{order}' => $this->order_id,
            '{delivery_date}'=> $this->delivery_date,
            '{delivery_time}'=> $this->delivery_time,
            '{site_title}' => get_bloginfo('name')
        );

        $find = apply_filters('pisol_pdpr_custom_short_code', $find, $this);

        return str_replace(array_keys($find), array_values($find), $msg);
    }

    function message(){
        
        $header = $this->header();
        $footer = $this->footer();
        
        $custom_message = '<p>'.$this->custom_message.'</p>';

        $delivery_detail = $this->deliveryDetails();
          
        return $this->replaceShortCode($header.$custom_message.$delivery_detail.$footer);
    }

    function header(){
        ob_start();  
        include('partials/email-header.php');
        $header = ob_get_contents();  
        ob_end_clean();
        return $header;
    }

    function footer(){
        ob_start();  
        include('partials/email-footer.php');
        $footer = ob_get_contents();  
        ob_end_clean();
        return $footer;
    }

    
    function sendEmail(){

        if(apply_filters('pisol_pdpr_disable_reminder', false, $this)) return;

        $headers = array('Content-Type: text/html; charset=UTF-8');
         
        if(wp_mail($this->customer_email, $this->subject, $this->message, $headers)){
           return true;
        }
        return false;
    }


    static function formatTimeForDisplay($times, $format = 'h:i A'){
        if(strpos($times,'-')){
            $times_array = explode("-",$times);
        }else{
            $times_array[] = $times;
        }

        $formated_array = array();
        foreach($times_array as $time){
            $formated_array[] = strtotime(trim($time)) ? date($format, strtotime(trim($time))) : trim($time);
        }
        $return  = "";
        if(count($formated_array) == 2){
            $return  .= $formated_array[0].' - '.$formated_array[1];
        }else{
            $return  .= $formated_array[0];
        }
        return $return;
    }

   

}