<?php

class pisol_order_reminder_event{
    
    function __construct(){
        add_action('woocommerce_update_order', array($this, 'registerEvent'), 10,2);
        add_action('pisol_order_reminder_event', array($this, 'event'),10, 1);
        $this->send_reminder_before = get_option('pi_email_reminder_trigger',30); // reminder event to trigger this minutes before delivery time       
    }

    function  registerEvent($order_id, $order = null){
        
        $delivery_date = $this->getDeliveryDate($order_id);
        if(empty($delivery_date)) return;

        $current_date = current_time('Y/m/d');

        if(strtotime($delivery_date) < strtotime($current_date)) return;
        
        $delivery_date_time  = $this->deliveryDateTime($order_id);
        $reminder_date_time = $this->reminderTime($delivery_date_time);
        
        $reminder_date_time_timestamp = $this->wp_strtotime($reminder_date_time);
        
        wp_schedule_single_event($reminder_date_time_timestamp, 'pisol_order_reminder_event', array($order_id));
    }

    function event($order_id){
       new pisol_pdpr_email_reminder($order_id);
    }

    function deliveryDateTime($order_id){
        $delivery_date = $this->getDeliveryDate($order_id);
        $delivery_time = $this->getDeliveryTime($order_id);
        $delivery_date_time = $delivery_date.' '.$delivery_time;
        return $delivery_date_time;
    }

    function reminderTime($delivery_date_time){
        $delivery_date_time_timestamp = strtotime($delivery_date_time);
        $reminder_date_time = date('Y/m/d H:i', strtotime("-{$this->send_reminder_before} minutes", $delivery_date_time_timestamp));
        return $reminder_date_time;
    }

    function getDeliveryDate($order_id){
        $order = wc_get_order($order_id);
        $date = $order->get_meta('pi_system_delivery_date', true );
        if(empty($date)) return null;

        return $date;
    }

    function getDeliveryTime($order_id){
        $order = wc_get_order($order_id);
        $time = $order->get_meta('pi_delivery_time', true );
        if(empty($time)) return null;

        return $this->getStartTime($time);
    }

    function getStartTime($time){
        if(strpos($time, '-') !== false){
            $times_array = explode("-",$time);
            return isset($times_array[0]) ? trim($times_array[0]) : null;
        }else{
            return !empty($time) ? trim($time): null;
        }

        return null;
    }

    /**
     * reference:
     * https://mediarealm.com.au/articles/wordpress-timezones-strtotime-date-functions/
     */
    function wp_strtotime($str) {
        // This function behaves a bit like PHP's StrToTime() function, but taking into account the Wordpress site's timezone
        // CAUTION: It will throw an exception when it receives invalid input - please catch it accordingly
        // From https://mediarealm.com.au/
        
        $tz_string = get_option('timezone_string');
        $tz_offset = get_option('gmt_offset', 0);
        
        if (!empty($tz_string)) {
            // If site timezone option string exists, use it
            $timezone = $tz_string;
        
        } elseif ($tz_offset == 0) {
            // get UTC offset, if it isn’t set then return UTC
            $timezone = 'UTC';
        
        } else {
            $timezone = $tz_offset;
            
            if(substr($tz_offset, 0, 1) != "-" && substr($tz_offset, 0, 1) != "+" && substr($tz_offset, 0, 1) != "U") {
                $timezone = "+" . $tz_offset;
            }
        }
        
        $datetime = new DateTime($str, new DateTimeZone($timezone));
        return $datetime->format('U');
      }
}

new pisol_order_reminder_event();

